@@ -1,5 +1,5 @@
 import {Component} from "@angular/core";
-import {Ng2BalloonMsgService} from "@synerty/ng2-balloon-msg";
+import { BalloonMsgService } from "@synerty/peek-plugin-base-js"
 import {
     ComponentLifecycleEventEmitter,
     extend,
@@ -25,7 +25,7 @@ export class EditSettingComponent extends ComponentLifecycleEventEmitter {
 
     loader: TupleLoader;
 
-    constructor(private balloonMsg: Ng2BalloonMsgService,
+    constructor(private balloonMsg: BalloonMsgService,
                 vortexService: VortexService) {
         super();
 
@@ -48,4 +48,4 @@ export class EditSettingComponent extends ComponentLifecycleEventEmitter {
             .catch(e => this.balloonMsg.showError(e));
     }
 
-}
\ No newline at end of file
+}
